@@ -30,7 +30,7 @@ def read_only(func):
 
 
 def launch_browser(BROWSER=False):
-    subprocess.Popen(
+    subprocess.call(
         'sleep 0.5;nohup %s http://127.0.0.1:%s/ &' % (
             BROWSER,
             settings.HTTP_PORT
